Filter out attn_from_ocmb FIR bits during TI analysis

Change-Id: I310abaa2b04eef7f13c8835da69eb2ac6df45f25
Signed-off-by: Caleb Palmer <cnpalmer@us.ibm.com>
diff --git a/analyzer/filter-root-cause.cpp b/analyzer/filter-root-cause.cpp
index 56d56af..e501f9d 100644
--- a/analyzer/filter-root-cause.cpp
+++ b/analyzer/filter-root-cause.cpp
@@ -289,11 +289,12 @@
             continue;
         }
 
         // Skip any signature with the 'recovered_error' or 'informational_only'
         // flags.
         if (i_rasData.isFlagSet(signature, rdf::RECOVERED_ERROR) ||
             i_rasData.isFlagSet(signature, rdf::INFORMATIONAL_ONLY) ||
-            i_rasData.isFlagSet(signature, rdf::MNFG_INFORMATIONAL_ONLY))
+            i_rasData.isFlagSet(signature, rdf::MNFG_INFORMATIONAL_ONLY) ||
+            i_rasData.isFlagSet(signature, rdf::ATTN_FROM_OCMB))
         {
             continue;
         }
@@ -289,11 +289,12 @@
         }
 
-        // Skip any signature with the 'recovered_error' or 'informational_only'
-        // flags.
+        // Skip any signature with the 'recovered_error', 'informational_only',
+        // or 'attn_from_ocmb' flags.
         if (i_rasData.isFlagSet(signature, rdf::RECOVERED_ERROR) ||
             i_rasData.isFlagSet(signature, rdf::INFORMATIONAL_ONLY) ||